package org.cyberchabudai.touch2matrix;

import java.io.BufferedOutputStream;
import java.io.IOException;
import java.net.Socket;
import java.net.ServerSocket;
import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.os.Handler;
import android.view.Display;
import android.view.Menu;
import android.view.MenuItem;
import android.view.WindowManager;
import android.widget.Toast;

public class Touch2matrixActivity extends Activity {
	private TouchView touchview;
	private static final int MENU_CLEAR = 0;
	
	private Socket mSocket = null;
	private static final int SERVER_PORT = 6000;
	private Handler handler;
	private BufferedOutputStream mSendData;
	private volatile boolean mRunstatus = true;
	
	/** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
		handler = new Handler(); 
		
        WindowManager mWinMan = (WindowManager) getSystemService(Context.WINDOW_SERVICE);
    	Display mDisp = mWinMan.getDefaultDisplay();
        touchview = new TouchView(this, mDisp.getWidth(), mDisp.getHeight());
        setContentView(touchview);

		/// create thread for data transfer //
        new Thread(new Runnable(){
        	public void run() {
        		try {
        			mSocket = new ServerSocket(SERVER_PORT).accept();
            		handler.post( new Runnable() {
        				public void run() {
                			Toast.makeText(Touch2matrixActivity.this, "Connected", Toast.LENGTH_SHORT).show();
        				}
        			}); 

            		mSendData = new BufferedOutputStream(mSocket.getOutputStream());
       				while(mRunstatus) {
       					mSendData.write(touchview.getLedPixData(), 0, 64);
       					mSendData.flush();
       					Thread.sleep(10);
                   	}
       				
        		} catch (IOException e) {
                   	/// process when connection error occurred ///
                   	e.printStackTrace();
                   	mRunstatus = false;
                	handler.post( new Runnable() {
            			public void run() {
                			Toast.makeText(Touch2matrixActivity.this, "Connection Failed", Toast.LENGTH_SHORT).show();
            			}
            		}); 
        		} catch (InterruptedException e) {
					e.printStackTrace();
                   	mRunstatus = false;
				} finally {
					try {
						if (mSendData != null) {
							mSendData.close();
						}
						if (mSocket != null) {
							mSocket.close();
						}
					} catch (IOException e) {
	                   	e.printStackTrace();
					}
				}

        	}
        }).start();
    }

    public void onStop() {
    	super.onStop();
		synchronized(this) {
			mRunstatus = false;
		}
    }
    
    
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		menu.add( 0, MENU_CLEAR, 0, "Clear" );
		return true;
	} 

	@Override
    public boolean onPrepareOptionsMenu(Menu menu) {
		return super.onPrepareOptionsMenu(menu);
    }


    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
        case MENU_CLEAR:
        	touchview.clearView();
        	break;
        }
        return true;
    }

}


