package org.cyberchabudai.touch2matrix;

import java.util.ArrayList;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Point;
import android.view.MotionEvent;
import android.view.View;

public class TouchView extends View {
	private ArrayList<Point> mDrawPoints = new ArrayList<Point>();
    private Canvas mLedCanvas;
	private Paint mPaint;
	private Bitmap mBitmap;

	private int mTouchX, mTouchY;
    private int mWidth, mHeight;

	private volatile static byte[] LedPixels;
    private static final int PIX_X = 34, PIX_Y = 18;
    private int mPixRateX, mPixRateY;
   
	public TouchView(Context context, int dispx, int dispy) {
		super(context);
		setFocusable(true);

        mWidth = dispx;
        mHeight = dispy;
        mPixRateX = (int)(mWidth / PIX_X);
        mPixRateY = (int)(mHeight / PIX_Y);
		LedPixels = new byte[64];

		mPaint = new Paint();
		mPaint.setColor(Color.BLUE);
		mPaint.setStyle(Paint.Style.FILL);
		mPaint.setAntiAlias(true);
		mPaint.setStrokeWidth(40);
		mPaint.setStrokeCap(Paint.Cap.ROUND);
		mPaint.setStrokeJoin(Paint.Join.ROUND);

		mBitmap = Bitmap.createBitmap(mWidth, mHeight, Bitmap.Config.ARGB_8888);
	}

	@Override
	public void onDraw(Canvas canvas) {
        super.onDraw(canvas);
		mLedCanvas = new Canvas(mBitmap);
		mLedCanvas.drawColor(Color.WHITE);
		
		for (int i = 1; i < mDrawPoints.size(); i++) {
			Point mPoint2 = mDrawPoints.get(i);
			Point mPoint1 = mDrawPoints.get(i-1);
			if (mPoint2.x < 0 || mPoint1.x < 0){
				continue;
			}
			mLedCanvas.drawLine(mPoint2.x, mPoint2.y, mPoint1.x, mPoint1.y, mPaint);
		}
		canvas.drawBitmap(mBitmap, 0f, 0f, null);

	}

	public void clearView () {
		mDrawPoints.clear();
		invalidate();
		for (int i = 0; i < 64; i++) {
			LedPixels[i] = 0x0;
		}
	}

	synchronized public byte[] getLedPixData () {
		return LedPixels;
	}
	
	@Override
	public void invalidate () {
		super.invalidate();

		int x=0, y=0;
		int pixnum;
		for (int i = 0; i < 16; i++) {
			x = 0;
			y += mPixRateY;
			for (int j = 0; j < 4 ; j++) {
				pixnum = i * 4 + j;
				x += mPixRateX;
				if (mBitmap.getPixel(x, y) == Color.BLUE) LedPixels[pixnum] |= 0x80;
				x += mPixRateX;
				if (mBitmap.getPixel(x, y) == Color.BLUE) LedPixels[pixnum] |= 0x40;
				x += mPixRateX;
				if (mBitmap.getPixel(x, y) == Color.BLUE) LedPixels[pixnum] |= 0x20;
				x += mPixRateX;
				if (mBitmap.getPixel(x, y) == Color.BLUE) LedPixels[pixnum] |= 0x10;
				x += mPixRateX;
				if (mBitmap.getPixel(x, y) == Color.BLUE) LedPixels[pixnum] |= 0x08;
				x += mPixRateX;
				if (mBitmap.getPixel(x, y) == Color.BLUE) LedPixels[pixnum] |= 0x04;
				x += mPixRateX;
				if (mBitmap.getPixel(x, y) == Color.BLUE) LedPixels[pixnum] |= 0x02;
				x += mPixRateX;
				if (mBitmap.getPixel(x, y) == Color.BLUE) LedPixels[pixnum] |= 0x01;
			}
		}
	}
	
	@Override
	public boolean onTouchEvent(MotionEvent event) {
		mTouchX = (int)event.getX();
		mTouchY = (int)event.getY();
		mDrawPoints.add(new Point(mTouchX, mTouchY));
		if (event.getAction() == MotionEvent.ACTION_UP) {
			mDrawPoints.add(new Point(-1, -1));
		}
		invalidate();
		return true;
	 }

}
